================
Usage - Commands
================

Benchpress provides a set of binaries for running and visualize the suite file :ref:`SuiteFile`.

bp-run
------
After you have created a benchmark suite file (see. :ref:`SuiteFile`), you can then use ``bp-run`` to *execute* the suite:

.. literalinclude:: autodoc_usage_commands/bp-run.txt

bp-cli
------
At any point, you can read the result of the finished executions within a benchmark suite file.
``bp-cli`` prints the benchmark results to the terminal:

.. literalinclude:: autodoc_usage_commands/bp-cli.txt

bp-cli-series
-------------

.. literalinclude:: autodoc_usage_commands/bp-cli-series.txt

bp-chart
--------

.. literalinclude:: autodoc_usage_commands/bp-chart.txt


bp-chart-series
---------------

.. literalinclude:: autodoc_usage_commands/bp-chart-series.txt

bp-raw
------

.. literalinclude:: autodoc_usage_commands/bp-raw.txt
